@@ -161,13 +161,17 @@ pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
+pref("gfx.downloadable_fonts.sanitize", true);
+//@line 176 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
+//@line 178 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 179 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 185 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -180,7 +184,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 195 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 201 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -524,9 +528,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 539 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 545 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 541 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 547 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -575,7 +579,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 592 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 598 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -718,7 +722,10 @@ pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
+pref("network.IDN.whitelist.lu", true);
 pref("network.IDN.whitelist.no", true);
+pref("network.IDN.whitelist.nu", true);
+pref("network.IDN.whitelist.nz", true);
 pref("network.IDN.whitelist.pl", true);
 pref("network.IDN.whitelist.pr", true);
 pref("network.IDN.whitelist.se", true);
@@ -728,12 +735,37 @@ pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
-// non-ccTLDs
+// IDN ccTLDs
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
+// cn, China, .<China> with variants
+pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
+pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// hk, Hong Kong, .<Hong Kong>
+pref("network.IDN.whitelist.xn--j6w193g", true);
+// ir, Iran, <.Iran> with variants
+pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
+pref("network.IDN.whitelist.xn--mgba3a4fra", true);
+// jo, Jordan, .<Al-Ordon>
+pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// sa, Saudi Arabia, .<al-Saudiah> with variants
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
+pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
+pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// tw, Taiwan, <.Taiwan> with variants
+pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
+pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
+
+// gTLDs
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
 pref("network.IDN.whitelist.org", true);
+pref("network.IDN.whitelist.tel", true);
 
 // NOTE: Before these can be removed, one of bug 414812's tests must be updated
 //       or it will likely fail!  Please CC jwalden+bmo on the bug associated
@@ -813,7 +845,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 835 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 869 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -872,6 +904,9 @@ pref("network.proxy.autoconfig_url", "");
 pref("network.proxy.autoconfig_retry_interval_min", 5);    // 5 seconds
 pref("network.proxy.autoconfig_retry_interval_max", 300);  // 5 minutes
 
+pref("network.buffer.cache.count", 24);
+pref("network.buffer.cache.size",  4096);
+
 pref("converter.html2txt.structs",          true); // Output structured phrases (strong, em, code, sub, sup, b, i, u)
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
@@ -1194,9 +1229,7 @@ pref("dom.max_script_run_time", 10);
 
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
-//
-//  NB: chosen to match dom.max_script_run_time by default
-pref("dom.ipc.plugins.timeoutSecs", 10);
+pref("dom.ipc.plugins.timeoutSecs", 45);
 
 pref("svg.enabled", true);
 pref("svg.smil.enabled", false);
@@ -1233,15 +1266,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1652 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 1687 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2076 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2111 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2279 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2314 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2375 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2410 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2378 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2413 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1511,20 +1544,20 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2650 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2685 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2718 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2753 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2744 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2779 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2764 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2799 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2766 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2801 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2772 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2807 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1561,15 +1594,12 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2814 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2849 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2819 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2854 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
 
 // Enable/Disable the orientation API for content
 pref("accelerometer.enabled", true);
-
-// Enable/Disable HTML5 parser
-pref("html5.enable", false);
